title:      HTML Embedding
desc:       Docnado Markdown Quick Reference
date:       2018/10/12
version:    1.0.0
template:   document
nav:        Document>HTML Embedding
percent:    100
authors:    enq@heinventions.com

Embedding HTML within Docserve documents is also supported.

We try to avoid it.

```markdown
<marquee>This is a Docserve document with embedded HTML.</marquee>
```

<marquee>This is a Docserve document with embedded HTML.</marquee>
